@@ -1,25 +1,23 @@
 use crate::{Parser, PingResult, Pinger};
-use regex::Regex;
+use lazy_regex::*;
 use std::net::Ipv6Addr;
 use std::time::Duration;
 
-lazy_static! {
-    static ref RE: Regex = Regex::new(r"time=(?:(?P<ms>[0-9]+).(?P<ns>[0-9]+)\s+ms)").unwrap();
-}
+pub static RE: Lazy<Regex> = lazy_regex!(r"time=(?:(?P<ms>[0-9]+).(?P<ns>[0-9]+)\s+ms)");
 
-#[derive(Default)]
 pub struct MacOSPinger {
     interval: Duration,
     interface: Option<String>,
 }
 
 impl Pinger for MacOSPinger {
-    fn set_interval(&mut self, interval: Duration) {
-        self.interval = interval;
-    }
+    type Parser = MacOSParser;
 
-    fn set_interface(&mut self, interface: Option<String>) {
-        self.interface = interface;
+    fn new(interval: Duration, interface: Option<String>) -> Self {
+        Self {
+            interval,
+            interface,
+        }
     }
 
     fn ping_args(&self, target: String) -> (&str, Vec<String>) {
